==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/WebresourceCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Webresource;
import microsoft.dynamics.crm.entity.request.SavedqueryvisualizationRequest;
import microsoft.dynamics.crm.entity.request.SolutionRequest;
import microsoft.dynamics.crm.entity.request.ThemeRequest;
import microsoft.dynamics.crm.entity.request.UserqueryvisualizationRequest;
import microsoft.dynamics.crm.entity.request.WebresourceRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class WebresourceCollectionRequest extends CollectionPageEntityRequest<Webresource, WebresourceRequest>{

    protected ContextPath contextPath;

    public WebresourceCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Webresource.class, cp -> new WebresourceRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SolutionCollectionRequest solution_configuration_webresource() {
        return new SolutionCollectionRequest(contextPath.addSegment("solution_configuration_webresource"), Optional.empty());
    }

    public SolutionRequest solution_configuration_webresource(String solutionid) {
        return new SolutionRequest(contextPath.addSegment("solution_configuration_webresource").addKeys(new NameValue(solutionid.toString())), Optional.empty());
    }

    public UserqueryvisualizationCollectionRequest webresource_userqueryvisualizations() {
        return new UserqueryvisualizationCollectionRequest(contextPath.addSegment("webresource_userqueryvisualizations"), Optional.empty());
    }

    public UserqueryvisualizationRequest webresource_userqueryvisualizations(String userqueryvisualizationid) {
        return new UserqueryvisualizationRequest(contextPath.addSegment("webresource_userqueryvisualizations").addKeys(new NameValue(userqueryvisualizationid.toString())), Optional.empty());
    }

    public SavedqueryvisualizationCollectionRequest webresource_savedqueryvisualizations() {
        return new SavedqueryvisualizationCollectionRequest(contextPath.addSegment("webresource_savedqueryvisualizations"), Optional.empty());
    }

    public SavedqueryvisualizationRequest webresource_savedqueryvisualizations(String savedqueryvisualizationid) {
        return new SavedqueryvisualizationRequest(contextPath.addSegment("webresource_savedqueryvisualizations").addKeys(new NameValue(savedqueryvisualizationid.toString())), Optional.empty());
    }

    public ThemeCollectionRequest lk_theme_logoid() {
        return new ThemeCollectionRequest(contextPath.addSegment("lk_theme_logoid"), Optional.empty());
    }

    public ThemeRequest lk_theme_logoid(String themeid) {
        return new ThemeRequest(contextPath.addSegment("lk_theme_logoid").addKeys(new NameValue(themeid.toString())), Optional.empty());
    }

    @Function(name = "RetrieveUnpublishedMultiple")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Webresource> retrieveUnpublishedMultiple() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublishedMultiple"), Webresource.class, _parameters, microsoft.dynamics.crm.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/WebresourceCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Webresource;
import microsoft.dynamics.crm.entity.request.SavedqueryvisualizationRequest;
import microsoft.dynamics.crm.entity.request.SolutionRequest;
import microsoft.dynamics.crm.entity.request.ThemeRequest;
import microsoft.dynamics.crm.entity.request.UserqueryvisualizationRequest;
import microsoft.dynamics.crm.entity.request.WebresourceRequest;

public class WebresourceCollectionRequest extends CollectionPageEntityRequest<Webresource, WebresourceRequest>{

    protected ContextPath contextPath;

    public WebresourceCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Webresource.class, cp -> new WebresourceRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SolutionCollectionRequest solution_configuration_webresource() {
        return new SolutionCollectionRequest(contextPath.addSegment("solution_configuration_webresource"), Optional.empty());
    }

    public SolutionRequest solution_configuration_webresource(String solutionid) {
        return new SolutionRequest(contextPath.addSegment("solution_configuration_webresource").addKeys(new NameValue(solutionid.toString())), Optional.empty());
    }

    public UserqueryvisualizationCollectionRequest webresource_userqueryvisualizations() {
        return new UserqueryvisualizationCollectionRequest(contextPath.addSegment("webresource_userqueryvisualizations"), Optional.empty());
    }

    public UserqueryvisualizationRequest webresource_userqueryvisualizations(String userqueryvisualizationid) {
        return new UserqueryvisualizationRequest(contextPath.addSegment("webresource_userqueryvisualizations").addKeys(new NameValue(userqueryvisualizationid.toString())), Optional.empty());
    }

    public SavedqueryvisualizationCollectionRequest webresource_savedqueryvisualizations() {
        return new SavedqueryvisualizationCollectionRequest(contextPath.addSegment("webresource_savedqueryvisualizations"), Optional.empty());
    }

    public SavedqueryvisualizationRequest webresource_savedqueryvisualizations(String savedqueryvisualizationid) {
        return new SavedqueryvisualizationRequest(contextPath.addSegment("webresource_savedqueryvisualizations").addKeys(new NameValue(savedqueryvisualizationid.toString())), Optional.empty());
    }

    public ThemeCollectionRequest lk_theme_logoid() {
        return new ThemeCollectionRequest(contextPath.addSegment("lk_theme_logoid"), Optional.empty());
    }

    public ThemeRequest lk_theme_logoid(String themeid) {
        return new ThemeRequest(contextPath.addSegment("lk_theme_logoid").addKeys(new NameValue(themeid.toString())), Optional.empty());
    }

    @Function(name = "RetrieveUnpublishedMultiple")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Webresource> retrieveUnpublishedMultiple() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublishedMultiple"), Webresource.class, _parameters);
    }

}
